@@ -156,20 +156,22 @@ sub do_work {
 		my ($update_rate_in_seconds, $is_update_aligned) = parse_update_rate($update_rate);
 		DEBUG "[DEBUG] update_rate $update_rate_in_seconds for $plugin on $nodedesignation";
 
+		my $new_data = 1;
+
 		if (! %service_data) {
 			# Check if this plugin has to be updated
 			if ($update_rate_in_seconds 
 				&& $self->is_fresh_enough($nodedesignation, $plugin, $update_rate_in_seconds)) {
 			    # It's fresh enough, skip this $service
 			    DEBUG "[DEBUG] $plugin is fresh enough, not updating it";
-			    next;
+			    $new_data = 0;
 			}
 
 			# __root__ is only a placeholder plugin for 
 			# an empty spoolfetch so we should ignore it 
 			# if asked to fetch it. 
 			# But we should still do everything after than.
-			if ($plugin ne "__root__") {
+			if ($new_data && $plugin ne "__root__") {
 				DEBUG "[DEBUG] No service data for $plugin, fetching it";
 				local $0 = "$0 -- fetch($plugin)";
 				%service_data = $self->{node}->fetch_service_data($plugin);
@@ -233,6 +235,8 @@ sub do_work {
 		    %{$all_service_configs{global}},
 		    %{$service_config{global}});
 
+		next if (!$new_data);
+
 		my $last_updated_timestamp = $self->_update_rrd_files(\%service_config, \%service_data);
 		if ($last_updated_timestamp) {
 		    $self->set_spoolfetch_timestamp($last_updated_timestamp);
@@ -251,7 +255,7 @@ sub do_work {
 	}
 
 	if ($EVAL_ERROR =~ m/^NO_SPOOLFETCH_DATA /) {
-	    INFO "[INFO] No spoofetch data for $nodedesignation";
+	    INFO "[INFO] No spoolfetch data for $nodedesignation";
 	    return;
 	} elsif ($EVAL_ERROR) {
 	    ERROR "[ERROR] Error in node communication with $nodedesignation: "
@@ -626,7 +630,7 @@ sub _update_rrd_files {
 	    DEBUG "[DEBUG] asking for a rrd of size : " . $ds_config->{graph_data_size};
 
 	    # Avoid autovivification (for multigraphs)
-	    my $first_epoch = (defined($service_data) and defined($service_data->{$ds_name})) ? ($service_data->{$ds_name}->{when}->[0]) : 0;
+	    my $first_epoch = (defined($service_data) and defined($service_data->{$ds_name}) and $service_data->{$ds_name}->{when}) ? ($service_data->{$ds_name}->{when}->[0]) : 0;
 	    my $rrd_file = $self->_create_rrd_file_if_needed($service, $ds_name, $ds_config, $first_epoch);
 
 	    if (defined($service_data) and defined($service_data->{$ds_name})) {
