@@ -21,8 +21,6 @@
 # perlpod.
 
 
-# $Id$
-
 =head1 NAME
 
 Munin::Plugin::Pgsql - Base module for PostgreSQL plugins for Munin
@@ -50,6 +48,11 @@ The plugins will by default connect to the 'template1' database, except for
 wildcard per-database plugins. This can be overridden using the PGDATABASE
 variable, but this is usually a bad idea.
 
+If you are using plugin for several postgres instances, you can customize
+graph title with the environment variable PGLABEL.
+
+Warning and critical can be customized by setting "warning" and "critical" env variables per plugin.
+
 =head2 Example
 
  [postgres_*]
@@ -57,6 +60,10 @@ variable, but this is usually a bad idea.
     env.PGUSER postgres
     env.PGPORT 5433
 
+  [postgres_connections_ALL]
+    env.warning :450
+    env.critical :500
+
 =head1 WILDCARD MATCHING
 
 Wildcard plugins based on this module will match on whatever type of object
@@ -120,7 +127,7 @@ use Munin::Plugin;
                 database is an older version than this, the plugin will exit
                 with an error.
  category       The category for this plugin. Copied directly to the config
-                output. Default 'PostgreSQL'.
+                output. Default 'db'.
  title          The title for this plugin. Copied directly to the config output.
  info           The info for this plugin. Copied directly to the config output.
  vlabel         The vertical label for the graph. Copied directly to the config
@@ -146,6 +153,8 @@ use Munin::Plugin;
                 if the plugin should be run on this machine. Must return a single
                 row, two columns columns. The first one is a boolean field
                 representing yes or no, the second one a reason for "no".
+ warning        The warning low and/or high thresholds.
+ critical       The critical low and/or high thresholds.
  graphdraw      The draw parameter for the graph. The default is LINE1.
  graphtype      The type parameter for the graph. The default is GAUGE.
  graphperiod    The period for the graph. Copied directly to the config output.
@@ -156,9 +165,9 @@ use Munin::Plugin;
  base           Used for graph_args --base. Default is 1000, set to 1024 when
                 returning sizes in Kb for example.
  wildcardfilter The SQL to substitute for when a wildcard plugin is run against
-                a specific entity, for example a database. All occurrances of
+                a specific entity, for example a database. All occurrences of
                 the string %%FILTER%% will be replaced with this string, and
-                for each occurance a parameter with the value of the filtering
+                for each occurrence a parameter with the value of the filtering
                 condition will be added to the DBI statement.
  paramdatabase  Makes the plugin connect to the database in the first parameter
                 (wildcard plugins only) instead of 'template1'.
@@ -201,7 +210,7 @@ sub new {
 
     my %defaults = (
         base      => 1000,
-        category  => 'PostgreSQL',
+        category  => 'db',
         graphdraw => 'LINE1',
         graphtype => 'GAUGE'
     );
@@ -214,6 +223,8 @@ sub new {
         title          => $args{title},
         info           => $args{info},
         vlabel         => $args{vlabel},
+        warning        => defined($ENV{'warning'}) ? $ENV{'warning'} : $args{warning},
+        critical       => defined($ENV{'critical'}) ? $ENV{'critical'} : $args{critical},
         graphdraw      => $args{graphdraw},
         graphtype      => $args{graphtype},
         graphperiod    => $args{graphperiod},
@@ -286,6 +297,8 @@ sub Config {
         }
         print "$l.min $self->{graphmin}\n" if (defined $self->{graphmin});
         print "$l.max $self->{graphmax}\n" if (defined $self->{graphmax});
+        print "$l.warning $self->{warning}\n" if (defined $self->{warning});
+        print "$l.critical $self->{critical}\n" if (defined $self->{critical});
         $firstrow = 0;
     }
 }
@@ -483,7 +496,9 @@ sub get_version {
     my $v = $r->[0]->[0];
     die "Unable to detect PostgreSQL version\n"
         unless ($v =~ /^(\d+)\.(\d+).*\b/);
-    $self->{detected_version} = "$1.$2";
+    # from PostgreSQL 10 on only the major version is needed
+    # see https://www.postgresql.org/support/versioning/
+    $self->{detected_version} = ($1 >= 10) ? "$1" : "$1.$2";
 }
 
 sub get_versioned_query {
